@@ -20,7 +20,7 @@
 NNS.seas <- function(variable, plot = TRUE){
 
   if(length(variable)<5){
-      return(data.table("Period" = 0, "Coefficient.of.Variance" = 0, "Variable.Coefficient.of.Variance" = 0, key = "Coefficient.of.Variance"))
+    return(data.table("Period" = 0, "Coefficient.of.Variance" = 0, "Variable.Coefficient.of.Variance" = 0, key = "Coefficient.of.Variance"))
   }
 
   variable_1 <- variable[1 : (length(variable) - 1)]
@@ -31,41 +31,41 @@ NNS.seas <- function(variable, plot = TRUE){
   instances <- numeric() ; instances_1 = numeric() ; instances_2 = numeric()
 
   if(mean(variable) != 0){
-      var.cov <- abs(sd(variable) / mean(variable))
+    var.cov <- abs(sd(variable) / mean(variable))
   } else {
-      var.cov <- Inf
+    var.cov <- Inf
   }
 
   for(i in 1 : (length(variable) / 2)){
-      reverse.var <- variable[seq(length(variable), 1, -i)]
-      reverse.var_1 <- variable_1[seq(length(variable_1), 1, -i)]
-      reverse.var_2 <- variable_2[seq(length(variable_2), 1, -i)]
+    reverse.var <- variable[seq(length(variable), 1, -i)]
+    reverse.var_1 <- variable_1[seq(length(variable_1), 1, -i)]
+    reverse.var_2 <- variable_2[seq(length(variable_2), 1, -i)]
 
-      test <- abs(sd(reverse.var) / mean(reverse.var))
-      test_1 <- abs(sd(reverse.var_1) / mean(reverse.var_1))
-      test_2 <- abs(sd(reverse.var_2) / mean(reverse.var_2))
-      if (test <= var.cov){
-          instances[i] <- i
-          output[i] <- test
-      } else {
-          instances[i] <- 0
-          output[i] <- 0
-      }
+    test <- abs(sd(reverse.var) / mean(reverse.var))
+    test_1 <- abs(sd(reverse.var_1) / mean(reverse.var_1))
+    test_2 <- abs(sd(reverse.var_2) / mean(reverse.var_2))
+    if (test <= var.cov){
+      instances[i] <- i
+      output[i] <- test
+    } else {
+      instances[i] <- 0
+      output[i] <- 0
+    }
 
     if (test_1 <= var.cov){
-        instances_1[i] <- i
-        output_1[i] <- test_1
+      instances_1[i] <- i
+      output_1[i] <- test_1
     } else {
-        instances_1[i] <- 0
-        output_1[i] <- 0
+      instances_1[i] <- 0
+      output_1[i] <- 0
     }
 
     if (test_2 <= var.cov){
-        instances_2[i] <- i
-        output_2[i] <- test_2
+      instances_2[i] <- i
+      output_2[i] <- test_2
     } else {
-        instances_2[i] <- 0
-        output_2[i] <- 0
+      instances_2[i] <- 0
+      output_2[i] <- 0
     }
   }
 
@@ -79,27 +79,26 @@ NNS.seas <- function(variable, plot = TRUE){
   insts <- sum(instances > 0) > 0
 
   if(insts){
-      n <- rep(var.cov, length(instances[index]))
+    n <- rep(var.cov, length(instances[index]))
 
-      M <- data.table("Period" = instances[index], "Coefficient.of.Variance" = output[index], "Variable.Coefficient.of.Variance" = n, key = "Coefficient.of.Variance")
+    M <- data.table("Period" = instances[index], "Coefficient.of.Variance" = output[index], "Variable.Coefficient.of.Variance" = n, key = "Coefficient.of.Variance")
   } else {
-      M <- data.table("Period" = 0, "Coefficient.of.Variance" = NA, "Variable.Coefficient.of.Variance" = n, key = "Coefficient.of.Variance")
+    M <- data.table("Period" = 1, "Coefficient.of.Variance" = NA, "Variable.Coefficient.of.Variance" = var.cov, key = "Coefficient.of.Variance")
   }
 
 
-  if(insts){
-      if(plot){
-          plot(instances[index], output[index], xlab = "Period", ylab = "Coefficient of Variance", main = "Seasonality Test", ylim = c(0, 2 * abs(sd(variable) / mean(variable))))
 
-          points(M[1, Period], M[1, Coefficient.of.Variance], pch = 19, col = 'red')
+    if(plot){
+      plot(instances[index], output[index], xlab = "Period", ylab = "Coefficient of Variance", main = "Seasonality Test", ylim = c(0, 2 * abs(sd(variable) / mean(variable))))
 
-          abline(h = abs(sd(variable) / mean(variable)), col = "red", lty = 5)
-          text(mean(instances[index]), abs(sd(variable) / mean(variable)), pos = 3, "Variable Coefficient of Variance", col = 'red')}
+      points(M[1, Period], M[1, Coefficient.of.Variance], pch = 19, col = 'red')
+
+      abline(h = abs(sd(variable) / mean(variable)), col = "red", lty = 5)
+      text(mean(instances[index]), abs(sd(variable) / mean(variable)), pos = 3, "Variable Coefficient of Variance", col = 'red')
+    }
 
     return(list("all.periods" = M,
                 "best.period" = M[1, Period]))
-    } else {
-        return(M)
-    }
+
 
 }
