@@ -1,38 +1,10 @@
-Uni.caus <- function(x, y, tau, plot = TRUE, scale = FALSE, time.series = FALSE){
+Uni.caus <- function(x, y, tau, plot = TRUE){
 
-  xy <- NNS.norm(cbind(x, y), linear = TRUE)
+  xy <- NNS.norm(cbind(x, y), linear = FALSE)
 
   NNS.x <- xy[ , 1]
   NNS.y <- xy[ , 2]
 
-
-
-  if(mean((NNS.x)) != mean(NNS.y)){
-    xy <- apply(cbind(x, y), 2, function(b) (b - min(b)) / (max(b) - min(b)))
-    x <- xy[ , 1]
-    y <- xy[ , 2]
-    if( time.series | scale |
-        LPM.ratio(2, mean(x), x) < .25 | LPM.ratio(2, mean(y), y) < .25 |
-        LPM.ratio(2, mean(x), x) > .75 | LPM.ratio(2, mean(y), y) > .75
-    )
-    {
-      x <- scale(x)[ , 1]
-      y <- scale(y)[ , 1]
-    }
-  }
-
-  if(mean(NNS.x) == mean(NNS.y)){
-      x <- NNS.x
-      y <- NNS.y
-  if( time.series | scale |
-      LPM.ratio(2, mean(x), x) < .25 | LPM.ratio(2, mean(y), y) < .25 |
-      LPM.ratio(2, mean(x), x) > .75 | LPM.ratio(2, mean(y), y) > .75
-      ){
-      x <- scale(x)[ , 1]
-      y <- scale(y)[ , 1]
-  }
-}
-
   min.length <- min(length(x), length(y))
 
   x.vectors <- list()
@@ -40,31 +12,32 @@ Uni.caus <- function(x, y, tau, plot = TRUE, scale = FALSE, time.series = FALSE)
 
   ## Create tau vectors
   if(tau > 0){
-    for (i in 0 : tau){
-      x.vectors[[paste('x.tau.', i, sep = "")]] <- numeric(0L)
-      y.vectors[[paste('y.tau.', i, sep = "")]] <- numeric(0L)
-      start <- tau - i + 1
-      end <- min.length - i
-      x.vectors[[i + 1]] <- x[start : end]
-      y.vectors[[i + 1]] <- y[start : end]
+    for (i in 0:tau){
+        x.vectors[[paste('x.tau.', i, sep = "")]] <- numeric(0L)
+        y.vectors[[paste('y.tau.', i, sep = "")]] <- numeric(0L)
+        start <- tau - i + 1
+        end <- min.length - i
+        x.vectors[[i + 1]] <- x[start : end]
+        y.vectors[[i + 1]] <- y[start : end]
     }
 
-    x.vectors.tau <- do.call(cbind,x.vectors)
-    y.vectors.tau <- do.call(cbind,y.vectors)
+      x.vectors.tau <- do.call(cbind,x.vectors)
+      y.vectors.tau <- do.call(cbind,y.vectors)
+
+      ## Normalize x to x.tau
+      x.norm.tau <- rowMeans(NNS.norm(x.vectors.tau))
+
+      ## Normalize y to y.tau
+      y.norm.tau <- rowMeans(NNS.norm(y.vectors.tau))
 
 
-    ## Normalize x to x.tau
-    x.norm.tau <- rowMeans(NNS.norm(x.vectors.tau))
-
-    ## Normalize y to y.tau
-    y.norm.tau <- rowMeans(NNS.norm(y.vectors.tau))
-  } else
-  {
-    x.norm.tau <- x
-    y.norm.tau <- y
+  } else {
+      x.norm.tau <- x
+      y.norm.tau <- y
   }
 
 
+
   ## Normalize x.norm.tau to y.norm.tau
   x.tau.y.tau <- NNS.norm(cbind(x.norm.tau, y.norm.tau))
   x.norm.to.y <- x.tau.y.tau[ , 1]
@@ -72,11 +45,11 @@ Uni.caus <- function(x, y, tau, plot = TRUE, scale = FALSE, time.series = FALSE)
 
 
   ## Conditional Probability from Normalized Variables P(x.norm.to.y | y.norm.to.x)
-  P.x.given.y <- UPM.ratio(1, min(x.norm.to.y), y.norm.to.x) - UPM.ratio(1, max(x.norm.to.y), y.norm.to.x)
+  P.x.given.y <- UPM.ratio(1, min(y.norm.to.x), x.norm.to.y) - UPM.ratio(1, max(y.norm.to.x), x.norm.to.y)
 
 
   ## Correlation of Normalized Variables
-  rho.x.y <- NNS.dep(x.norm.to.y, y.norm.to.x)$Dependence
+  rho.x.y <- NNS.dep(x.norm.to.y, y.norm.to.x)$Correlation
 
   Causation.x.given.y <- P.x.given.y * rho.x.y
 
